
#declare RedCol = color srgb < 1, 40 / 255, 0 >;
#declare OrangeCol = color srgb < 1, 155 / 255, 0 >;
#declare Clear = color srgbft < 0, 0, 0, 0, 1>;

#declare WaxCol = color srgb < 1, 1, 0.85 >;

#declare FireMix = density{ wrinkles density_map{ [0.4 RedCol ][0.5 OrangeCol][0.6 RedCol] } }

#declare PointsNumber = 5;
#declare PentagramRadius = 4;
#declare PentagramScaleFactor = 12 / PentagramRadius / 2;
#declare CandlesRadiusDistance = 4.7 * PentagramScaleFactor;
#declare CandleRadius = 0.15;
#declare LineRadius = 0.01;

#declare CandleHighnessSeed = seed( 79230 );
#declare CandleFireSeed = seed( 655 );

#declare PentagramCirclePoints = array[PointsNumber] { < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0> }
#declare CandlesCoordinates = array[PointsNumber] { < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0>, < 0, 0, 0> }

#for( It, 0, PointsNumber - 1 )
	#declare PentagramCirclePoints[It] = < 0, 0, PentagramRadius >;
	#declare PentagramCirclePoints[It] = vrotate(PentagramCirclePoints[It], < 0, 360 / PointsNumber * It, 0>);
	
	#declare CandlesCoordinates[It] = < 0, 100, CandlesRadiusDistance >;
	#declare CandlesCoordinates[It] = vrotate(CandlesCoordinates[It], < 0, 360 / PointsNumber * It, 0>);
#end

//Link pentagram points
#declare Pentagram =
union{
	torus{ PentagramRadius, LineRadius sturm }
	cylinder{ PentagramCirclePoints[0], PentagramCirclePoints[2], LineRadius }
	cylinder{ PentagramCirclePoints[0], PentagramCirclePoints[3], LineRadius }
	cylinder{ PentagramCirclePoints[1], PentagramCirclePoints[3], LineRadius }
	cylinder{ PentagramCirclePoints[1], PentagramCirclePoints[4], LineRadius }
	cylinder{ PentagramCirclePoints[2], PentagramCirclePoints[4], LineRadius } 
	pigment{ color srgbft <0, 0, 0, 0, 1> }
	hollow no_shadow
	interior{ 
		media{
			emission color srgb 8 samples 1, 30 intervals 10
			density{ bozo density_map{
									[0 Clear ]
									[0.4 Clear ]
									[0.4 FireMix ]
									[0.7 FireMix ]
									[0.7 Clear ]
									[1 Clear ]
								}
				scale 0.1
			}
		}
	}
}

#macro MakeCandle( Position, Y_Rotation, CandleHighness, FireTurb )
	union{
		difference{
			cylinder{ <0,0,0> , <0,CandleHighness,0>, CandleRadius pigment{ WaxCol } }
			sphere{ <0,0,0>, CandleRadius scale < 0.85, 0.35, 0.85 > 
					translate CandleHighness * y
					pigment{ WaxCol } 
					finish{ specular 0.2 roughness 0.01 }
			}
		}
		//Candle fire stalk
		cylinder{< 0,CandleHighness - CandleRadius, 0>,< 0, CandleHighness + CandleRadius, 0 >, 0.01 pigment{ color srgb 0.1 } }
		sphere{ 0, CandleRadius * 3 / 4
			hollow no_shadow
			pigment{ color srgbft <0, 0, 0, 0, 1> } 
			interior{ 
				media{
					emission color srgb 3 samples 1, 30 intervals 4
					density{ spherical density_map{
												[ 0 color srgb 0 ]
												[ 0.2 color srgbt < 1, 0.25, 0, 0.8 > ]
												[ 0.45 color srgbt < 1, 0.25, 0, 0.8 > ]
												[ 0.45 color srgb < 1, 1, 0.75 > ]
										}
						warp{ turbulence FireTurb }
					}
				}
			}
			scale < 0.5, 0.85, 0.5 >
			translate ( CandleHighness + CandleRadius ) * y
		}
		light_source{ < 0, CandleHighness + CandleRadius * 2, 0 > < 1, 1, 0.95 > * 0.25 fade_distance 2 fade_power 1 }
		
		rotate Y_Rotation * y
		translate Position
	}
#end
